@@ -333,7 +333,8 @@ class BaseDiagramWidget(QSplitter):
             self.object_editor_table.setModel(None)
             return False
 
-    def delete_element_utility_function(self, device: ALL_DEV_TYPES, propagate: bool = True):
+    def delete_element_utility_function(self, device: ALL_DEV_TYPES, propagate: bool = True,
+                                        graphic_object: QGraphicsItem | None = None):
         """
         This function is a utility function to call this function in other diagrams through the GUI
         :param device: ALL_DEV_TYPES
@@ -341,7 +342,9 @@ class BaseDiagramWidget(QSplitter):
         :return:
         """
         self.diagram.delete_device(device=device)
-        graphic_object: QGraphicsItem = self.graphics_manager.delete_device(device=device)
+
+        if graphic_object is None:
+            graphic_object: QGraphicsItem = self.graphics_manager.delete_device(device=device)
 
         if graphic_object is not None:
             self._remove_from_scene(graphic_object)
@@ -375,7 +378,7 @@ class BaseDiagramWidget(QSplitter):
 
             dlg = DeleteDialogue(
                 names_list=[f"{device.device_type.value}: "
-                              f"{device.name}"
+                            f"{device.name}"
                             for device in extended_lst],
                 delete_from_db=delete_from_db,
                 title="Delete Selected",
@@ -387,7 +390,6 @@ class BaseDiagramWidget(QSplitter):
 
             if dlg.is_accepted:
                 for device in extended_lst:
-
                     self.remove_element(device=device,
                                         graphic_object=self.graphics_manager.query(elm=device),
                                         delete_from_db=dlg.delete_from_db)
@@ -413,7 +415,16 @@ class BaseDiagramWidget(QSplitter):
         :param elements: list of elements to delete
         """
         for elm in elements:
-            self.delete_element_utility_function(elm)
+            graphic_object: QGraphicsItem = self.graphics_manager.delete_device(device=elm)
+
+            # this calls internally to delete_element_utility_function
+            self.remove_element(
+                device=elm,
+                graphic_object=graphic_object
+            )
+
+            self.delete_element_utility_function(elm,
+                                                 graphic_object=graphic_object)
 
     def set_time_index(self, time_index: Union[int, None]):
         """
